==> skema-0.0.41.tar.gz: skema-0.0.41/setup.py <==


from setuptools import setup


setup(
    name='skema',
    version=open('VERSION').read().strip(),

    description='Schema language that compiles to json schema',
    # long_description='',
    long_description_content_type='text/markdown',

    author='Tommaso De Rossi',
    author_email='daer.tommy@gmail.com',
    license='Apache Software License 2.0',

    url='https://github.com/remorses/schema',
    keywords=['schema', 'jsonschema', 'alternative', 'readable'],
    install_requires=[x for x in open('./requirements.txt').read().strip().split('\n') if x.strip()],
    package_data={'': ['*.yaml', '*.json', '*.yml']},
    include_package_data=True,
    classifiers=[
        # How mature is this project? Common values are
        # 'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Information Technology',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Apache Software License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    packages=['skema', 'skema.fake_data', 'skema.generate', 'skema.infer'],
    scripts=[
        'bin/skema-generate-python',
        'bin/skema-generate-typescript',
        'bin/skema-generate-jsonschema',
        'bin/skema-generate-graphql',
        'bin/skema-gen',

        'bin/skema.infer',
        'bin/skema.generate',
    ],

)

==> skema-0.0.77.tar.gz: skema-0.0.77/setup.py <==


from setuptools import setup


setup(
    name='skema',
    version=open('VERSION').read().strip(),

    description='Schema language that compiles to json schema',
    # long_description='',
    long_description_content_type='text/markdown',

    author='Tommaso De Rossi',
    author_email='daer.tommy@gmail.com',
    license='Apache Software License 2.0',

    url='https://github.com/remorses/schema',
    keywords=['schema', 'jsonschema', 'alternative', 'readable'],
    install_requires=[x for x in open('./requirements.txt').read().strip().split('\n') if x.strip()],
    package_data={'': ['*.yaml', '*.json', '*.yml', 'VERSION']},
    include_package_data=True,
    classifiers=[
        # How mature is this project? Common values are
        # 'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Information Technology',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Apache Software License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    packages=['skema', 'skema.fake_data', 'skema.generate', 'skema.infer'],
    scripts=[
        'bin/skema-gen',
        'bin/skema',
        'bin/skema.infer',
        'bin/skema.generate',
    ],

)
